@@ -27,15 +27,16 @@
 #' BesselA(m=15, t^2/4, nu) * (t/2)^nu
 BesselA <- function(m, x, nu){
   stopifnot(
-    is.vector(nu) && is.atomic(nu),
+    isNumericOrComplex(nu),
     length(nu) == 1L,
-    is.numeric(nu) || is.complex(nu),
     Re(nu) > -1
   )
   if(is.matrix(x)){
     p <- nrow(x)
-  }else{
+  }else if(isNumericOrComplex(x)){
     p <- length(x)
+  }else{
+    stop("Invalid `x` argument")
   }
-  hypergeomPFQ(m, NULL, nu+(p+1)/2, -x) / mvgamma(nu+(p+1)/2, p)
+  .hypergeomPFQ(m, NULL, nu+(p+1)/2, -x, alpha = 2) / mvgamma(nu+(p+1)/2, p)
 }
